xsdata.formats package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.dataclass
   xsdata.formats.plantuml

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.bindings
   xsdata.formats.converters
   xsdata.formats.mixins

Module contents
---------------

.. automodule:: xsdata.formats
   :members:
   :undoc-members:
   :show-inheritance:
